@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,16 +21,20 @@
 
 #include <QSyntaxHighlighter>
 
-namespace Akonadi
-{
-namespace Search
-{
+namespace Akonadi {
+namespace Search {
 class Rule
 {
 public:
-    Rule() {}
+    Rule()
+    {
+    }
+
     Rule(const QRegExp &r, const QTextCharFormat &f)
-        : pattern(r), format(f) {}
+        : pattern(r)
+        , format(f)
+    {
+    }
 
     QRegExp pattern;
     QTextCharFormat format;
