@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -37,8 +37,8 @@ class Akonadi::Search::PIM::IndexedItemsPrivate
 public:
     IndexedItemsPrivate()
     {
-
     }
+
     QString dbPath(const QString &dbName) const;
     QString emailIndexingPath() const;
     QString collectionIndexingPath() const;
@@ -176,10 +176,9 @@ void IndexedItemsPrivate::findIndexed(QSet<Akonadi::Item::Id> &indexed, Akonadi:
 }
 
 IndexedItems::IndexedItems(QObject *parent)
-    : QObject(parent),
-      d(new Akonadi::Search::PIM::IndexedItemsPrivate())
+    : QObject(parent)
+    , d(new Akonadi::Search::PIM::IndexedItemsPrivate())
 {
-
 }
 
 IndexedItems::~IndexedItems()
