@@ -76,7 +76,11 @@ QStringList XapianTermGenerator::termList(const QString &text)
             }
 
             str = cleanString.normalized(QString::NormalizationForm_KC);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             list << str.split(QLatin1Char('_'), QString::SkipEmptyParts);
+#else
+            list << str.split(QLatin1Char('_'), Qt::SkipEmptyParts);
+#endif
         }
     }
 
@@ -89,7 +93,7 @@ void XapianTermGenerator::indexText(const QString &text, const QString &prefix,
     //const QByteArray ta = text.toUtf8();
     //m_termGen.index_text(ta.constData(), wdfInc, par.constData());
 
-    QStringList terms = termList(text);
+    const QStringList terms = termList(text);
     for (const QString &term : terms) {
         QByteArray arr = term.toUtf8();
 
@@ -110,4 +114,3 @@ void XapianTermGenerator::setPosition(int position)
 {
     m_position = position;
 }
-
